@@ -24,15 +24,17 @@ pub struct Expr {
 #[derive(Debug, Clone)]
 pub enum SimpleExpr {
     Column(ColumnRef),
+    Tuple(Vec<SimpleExpr>),
     Unary(UnOper, Box<SimpleExpr>),
     FunctionCall(Function, Vec<SimpleExpr>),
     Binary(Box<SimpleExpr>, BinOper, Box<SimpleExpr>),
-    SubQuery(Box<SelectStatement>),
+    SubQuery(Box<SubQueryStatement>),
     Value(Value),
     Values(Vec<Value>),
     Custom(String),
     CustomWithValues(String, Vec<Value>),
     Keyword(Keyword),
+    AsEnum(DynIden, Box<SimpleExpr>),
 }
 
 impl Expr {
@@ -51,6 +53,58 @@ impl Expr {
         }
     }
 
+    /// Express the asterisk without table prefix.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(Expr::asterisk())
+    ///     .from(Char::Table)
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT * FROM `character`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT * FROM "character""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT * FROM "character""#
+    /// );
+    /// ```
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .and_where(Expr::col((Char::Table, Char::SizeW)).eq(1))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` = 1"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" = 1"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" = 1"#
+    /// );
+    /// ```
+    pub fn asterisk() -> Self {
+        Self::col(ColumnRef::Asterisk)
+    }
+
     /// Express the target column without table prefix.
     ///
     /// # Examples
@@ -74,7 +128,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` = 1"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "size_w" = 1"#
     /// );
     /// ```
     ///
@@ -97,7 +151,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` = 1"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" = 1"#
     /// );
     /// ```
     pub fn col<T>(n: T) -> Self
@@ -107,6 +161,99 @@ impl Expr {
         Self::new_with_left(SimpleExpr::Column(n.into_column_ref()))
     }
 
+    /// Wraps tuple of `SimpleExpr`, can be used for tuple comparison
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .and_where(
+    ///         Expr::tuple([Expr::col(Char::SizeW).into_simple_expr(), Expr::value(100)])
+    ///             .less_than(Expr::tuple([Expr::value(500), Expr::value(100)])))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE (`size_w`, 100) < (500, 100)"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE ("size_w", 100) < (500, 100)"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE ("size_w", 100) < (500, 100)"#
+    /// );
+    /// ```
+    pub fn tuple<I>(n: I) -> Self
+    where
+        I: IntoIterator<Item = SimpleExpr>,
+    {
+        Expr::expr(SimpleExpr::Tuple(
+            n.into_iter().collect::<Vec<SimpleExpr>>(),
+        ))
+    }
+
+    /// Express the asterisk with table prefix.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(Expr::asterisk())
+    ///     .from(Char::Table)
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT * FROM `character`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT * FROM "character""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT * FROM "character""#
+    /// );
+    /// ```
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(Expr::table_asterisk(Char::Table))
+    ///     .column((Font::Table, Font::Name))
+    ///     .from(Char::Table)
+    ///     .inner_join(Font::Table, Expr::tbl(Char::Table, Char::FontId).equals(Font::Table, Font::Id))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`.*, `font`.`name` FROM `character` INNER JOIN `font` ON `character`.`font_id` = `font`.`id`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character".*, "font"."name" FROM "character" INNER JOIN "font" ON "character"."font_id" = "font"."id""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character".*, "font"."name" FROM "character" INNER JOIN "font" ON "character"."font_id" = "font"."id""#
+    /// );
+    /// ```
+    pub fn table_asterisk<T>(t: T) -> Self
+    where
+        T: IntoIden,
+    {
+        Self::col(ColumnRef::TableAsterisk(t.into_iden()))
+    }
+
     /// Express the target column with table prefix.
     ///
     /// # Examples
@@ -130,7 +277,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` = 1"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" = 1"#
     /// );
     /// ```
     pub fn tbl<T, C>(t: T, c: C) -> Self
@@ -166,7 +313,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 AND 2.5 AND '3'"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 AND 2.5 AND '3'"#
     /// );
     /// ```
     pub fn val<V>(v: V) -> Self
@@ -199,7 +346,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE IFNULL(`size_w`, 0) > 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE IFNULL("size_w", 0) > 2"#
     /// );
     /// ```
     #[allow(clippy::self_named_constructors)]
@@ -232,7 +379,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 AND 2.5 AND '3'"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 AND 2.5 AND '3'"#
     /// );
     /// ```
     pub fn value<V>(v: V) -> SimpleExpr
@@ -265,7 +412,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 = 1"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 = 1"#
     /// );
     /// ```
     pub fn cust(s: &str) -> SimpleExpr {
@@ -296,7 +443,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `id` = 1 AND 6 = 2 * 3"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "id" = 1 AND 6 = 2 * 3"#
     /// );
     /// ```
     /// ```
@@ -367,7 +514,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 'What!' = 'Nothing' AND `id` = 1"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 'What!' = 'Nothing' AND "id" = 1"#
     /// );
     /// ```
     pub fn eq<V>(self, v: V) -> SimpleExpr
@@ -401,7 +548,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 'Morning' <> 'Good' AND `id` <> 1"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 'Morning' <> 'Good' AND "id" <> 1"#
     /// );
     /// ```
     pub fn ne<V>(self, v: V) -> SimpleExpr
@@ -435,7 +582,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`font_id` = `font`.`id`"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."font_id" = "font"."id""#
     /// );
     /// ```
     pub fn equals<T, C>(self, t: T, c: C) -> SimpleExpr
@@ -472,7 +619,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` > 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" > 2"#
     /// );
     /// ```
     pub fn gt<V>(self, v: V) -> SimpleExpr
@@ -482,6 +629,41 @@ impl Expr {
         self.bin_oper(BinOper::GreaterThan, SimpleExpr::Value(v.into()))
     }
 
+    /// Express a greater than (`>`) expression to another expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .and_where(
+    ///         Expr::tbl(Char::Table, Char::SizeW)
+    ///         .greater_than(Expr::tbl(Char::Table, Char::SizeH))
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` > `character`.`size_h`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" > "character"."size_h""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" > "character"."size_h""#
+    /// );
+    /// ```
+    pub fn greater_than<T>(self, expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.binary(BinOper::GreaterThan, expr)
+    }
     /// Express a greater than or equal (`>=`) expression.
     ///
     /// # Examples
@@ -505,7 +687,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` >= 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" >= 2"#
     /// );
     /// ```
     pub fn gte<V>(self, v: V) -> SimpleExpr
@@ -515,6 +697,42 @@ impl Expr {
         self.bin_oper(BinOper::GreaterThanOrEqual, SimpleExpr::Value(v.into()))
     }
 
+    /// Express a greater than or equal (`>=`) expression to another expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .and_where(
+    ///         Expr::tbl(Char::Table, Char::SizeW)
+    ///         .greater_or_equal(Expr::tbl(Char::Table, Char::SizeH))
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` >= `character`.`size_h`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" >= "character"."size_h""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" >= "character"."size_h""#
+    /// );
+    /// ```
+    pub fn greater_or_equal<T>(self, expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.binary(BinOper::GreaterThanOrEqual, expr)
+    }
+
     /// Express a less than (`<`) expression.
     ///
     /// # Examples
@@ -538,7 +756,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` < 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" < 2"#
     /// );
     /// ```
     pub fn lt<V>(self, v: V) -> SimpleExpr
@@ -548,6 +766,42 @@ impl Expr {
         self.bin_oper(BinOper::SmallerThan, SimpleExpr::Value(v.into()))
     }
 
+    /// Express a less than (`<`) expression to another expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .and_where(
+    ///         Expr::tbl(Char::Table, Char::SizeW)
+    ///         .less_than(Expr::tbl(Char::Table, Char::SizeH))
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` < `character`.`size_h`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" < "character"."size_h""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" < "character"."size_h""#
+    /// );
+    /// ```
+    pub fn less_than<T>(self, expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.binary(BinOper::SmallerThan, expr)
+    }
+
     /// Express a less than or equal (`<=`) expression.
     ///
     /// # Examples
@@ -571,7 +825,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` <= 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" <= 2"#
     /// );
     /// ```
     pub fn lte<V>(self, v: V) -> SimpleExpr
@@ -581,6 +835,42 @@ impl Expr {
         self.bin_oper(BinOper::SmallerThanOrEqual, SimpleExpr::Value(v.into()))
     }
 
+    /// Express a less than or equal (`<=`) expression to another expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .and_where(
+    ///         Expr::tbl(Char::Table, Char::SizeW)
+    ///         .less_or_equal(Expr::tbl(Char::Table, Char::SizeH))
+    ///     )
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` <= `character`.`size_h`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" <= "character"."size_h""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" <= "character"."size_h""#
+    /// );
+    /// ```
+    pub fn less_or_equal<T>(self, expr: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.binary(BinOper::SmallerThanOrEqual, expr)
+    }
+
     /// Express an arithmetic addition operation.
     ///
     /// # Examples
@@ -604,7 +894,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 + 1 = 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 + 1 = 2"#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -638,7 +928,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 - 1 = 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 - 1 = 2"#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -672,7 +962,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 * 1 = 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 * 1 = 2"#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -706,7 +996,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE 1 / 1 = 2"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE 1 / 1 = 2"#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -740,7 +1030,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` BETWEEN 1 AND 10"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" BETWEEN 1 AND 10"#
     /// );
     /// ```
     pub fn between<V>(self, a: V, b: V) -> SimpleExpr
@@ -773,7 +1063,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` NOT BETWEEN 1 AND 10"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" NOT BETWEEN 1 AND 10"#
     /// );
     /// ```
     pub fn not_between<V>(self, a: V, b: V) -> SimpleExpr
@@ -820,7 +1110,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`character` LIKE 'Ours\'%'"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."character" LIKE 'Ours\'%'"#
     /// );
     /// ```
     pub fn like(self, v: &str) -> SimpleExpr {
@@ -860,7 +1150,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` IS NULL"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" IS NULL"#
     /// );
     /// ```
     #[allow(clippy::wrong_self_convention)]
@@ -891,7 +1181,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `character`.`size_w` IS NOT NULL"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "character"."size_w" IS NOT NULL"#
     /// );
     /// ```
     #[allow(clippy::wrong_self_convention)]
@@ -899,6 +1189,40 @@ impl Expr {
         self.bin_oper(BinOper::IsNot, SimpleExpr::Keyword(Keyword::Null))
     }
 
+    /// Create any binary operation
+    ///
+    /// # Examples
+    /// ```
+    /// use sea_query::{*, tests_cfg::*};
+    ///
+    /// let query = Query::select()
+    ///     .columns(vec![Char::Character, Char::SizeW, Char::SizeH])
+    ///     .from(Char::Table)
+    ///     .cond_where(all![
+    ///         Expr::col(Char::SizeW).binary(BinOper::SmallerThan, Expr::value(10)),
+    ///         Expr::col(Char::SizeW).binary(BinOper::GreaterThan, Expr::col(Char::SizeH))
+    ///     ])
+    ///     .to_owned();
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` < 10 AND `size_w` > `size_h`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "size_w" < 10 AND "size_w" > "size_h""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "size_w" < 10 AND "size_w" > "size_h""#
+    /// );
+    /// ```
+    pub fn binary<T>(self, operation: BinOper, right: T) -> SimpleExpr
+    where
+        T: Into<SimpleExpr>,
+    {
+        self.bin_oper(operation, right.into())
+    }
+
     /// Negates an expression with `NOT`.
     ///
     /// # Examples
@@ -922,7 +1246,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE NOT `character`.`size_w` IS NULL"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE NOT "character"."size_w" IS NULL"#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -952,7 +1276,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT MAX(`character`.`size_w`) FROM `character`"#
+    ///     r#"SELECT MAX("character"."size_w") FROM "character""#
     /// );
     /// ```
     pub fn max(mut self) -> SimpleExpr {
@@ -982,7 +1306,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT MIN(`character`.`size_w`) FROM `character`"#
+    ///     r#"SELECT MIN("character"."size_w") FROM "character""#
     /// );
     /// ```
     pub fn min(mut self) -> SimpleExpr {
@@ -1012,7 +1336,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT SUM(`character`.`size_w`) FROM `character`"#
+    ///     r#"SELECT SUM("character"."size_w") FROM "character""#
     /// );
     /// ```
     pub fn sum(mut self) -> SimpleExpr {
@@ -1042,7 +1366,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT COUNT(`character`.`size_w`) FROM `character`"#
+    ///     r#"SELECT COUNT("character"."size_w") FROM "character""#
     /// );
     /// ```
     pub fn count(mut self) -> SimpleExpr {
@@ -1072,7 +1396,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT IFNULL(`character`.`size_w`, 0) FROM `character`"#
+    ///     r#"SELECT IFNULL("character"."size_w", 0) FROM "character""#
     /// );
     /// ```
     pub fn if_null<V>(mut self, v: V) -> SimpleExpr
@@ -1109,7 +1433,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `id` FROM `character` WHERE `character`.`size_w` IN (1, 2, 3)"#
+    ///     r#"SELECT "id" FROM "character" WHERE "character"."size_w" IN (1, 2, 3)"#
     /// );
     /// ```
     /// Empty value list
@@ -1132,7 +1456,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `id` FROM `character` WHERE 1 = 2"#
+    ///     r#"SELECT "id" FROM "character" WHERE 1 = 2"#
     /// );
     /// ```
     #[allow(clippy::wrong_self_convention)]
@@ -1171,7 +1495,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `id` FROM `character` WHERE `character`.`size_w` NOT IN (1, 2, 3)"#
+    ///     r#"SELECT "id" FROM "character" WHERE "character"."size_w" NOT IN (1, 2, 3)"#
     /// );
     /// ```
     /// Empty value list
@@ -1194,7 +1518,7 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `id` FROM `character` WHERE 1 = 1"#
+    ///     r#"SELECT "id" FROM "character" WHERE 1 = 1"#
     /// );
     /// ```
     #[allow(clippy::wrong_self_convention)]
@@ -1237,13 +1561,15 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` IN (SELECT 3 + 2 * 2)"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "size_w" IN (SELECT 3 + 2 * 2)"#
     /// );
     /// ```
     #[allow(clippy::wrong_self_convention)]
     pub fn in_subquery(mut self, sel: SelectStatement) -> SimpleExpr {
         self.bopr = Some(BinOper::In);
-        self.right = Some(SimpleExpr::SubQuery(Box::new(sel)));
+        self.right = Some(SimpleExpr::SubQuery(Box::new(
+            sel.into_sub_query_statement(),
+        )));
         self.into()
     }
 
@@ -1274,13 +1600,15 @@ impl Expr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE `size_w` NOT IN (SELECT 3 + 2 * 2)"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE "size_w" NOT IN (SELECT 3 + 2 * 2)"#
     /// );
     /// ```
     #[allow(clippy::wrong_self_convention)]
     pub fn not_in_subquery(mut self, sel: SelectStatement) -> SimpleExpr {
         self.bopr = Some(BinOper::NotIn);
-        self.right = Some(SimpleExpr::SubQuery(Box::new(sel)));
+        self.right = Some(SimpleExpr::SubQuery(Box::new(
+            sel.into_sub_query_statement(),
+        )));
         self.into()
     }
 
@@ -1424,6 +1752,57 @@ impl Expr {
         self.into()
     }
 
+    /// Express a `AS enum` expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(Expr::col(Char::FontSize).as_enum(Alias::new("text")))
+    ///     .from(Char::Table)
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT `font_size` FROM `character`"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT CAST("font_size" AS text) FROM "character""#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT "font_size" FROM "character""#
+    /// );
+    ///
+    /// let query = Query::insert()
+    ///     .into_table(Char::Table)
+    ///     .columns(vec![Char::FontSize])
+    ///     .exprs_panic(vec![Expr::val("large").as_enum(Alias::new("FontSizeEnum"))])
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"INSERT INTO `character` (`font_size`) VALUES ('large')"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"INSERT INTO "character" ("font_size") VALUES (CAST('large' AS FontSizeEnum))"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"INSERT INTO "character" ("font_size") VALUES ('large')"#
+    /// );
+    /// ```
+    pub fn as_enum<T>(self, type_name: T) -> SimpleExpr
+    where
+        T: IntoIden,
+    {
+        SimpleExpr::AsEnum(type_name.into_iden(), Box::new(self.into()))
+    }
+
     fn func_with_args(func: Function, args: Vec<SimpleExpr>) -> SimpleExpr {
         let mut expr = Expr::new();
         expr.func = Some(func);
@@ -1448,21 +1827,20 @@ impl Expr {
     }
 }
 
-#[allow(clippy::from_over_into)]
-impl Into<SimpleExpr> for Expr {
+impl From<Expr> for SimpleExpr {
     /// Convert into SimpleExpr. Will panic if this Expr is missing an operand
-    fn into(self) -> SimpleExpr {
-        if let Some(uopr) = self.uopr {
-            SimpleExpr::Unary(uopr, Box::new(self.left.unwrap()))
-        } else if let Some(bopr) = self.bopr {
+    fn from(src: Expr) -> Self {
+        if let Some(uopr) = src.uopr {
+            SimpleExpr::Unary(uopr, Box::new(src.left.unwrap()))
+        } else if let Some(bopr) = src.bopr {
             SimpleExpr::Binary(
-                Box::new(self.left.unwrap()),
+                Box::new(src.left.unwrap()),
                 bopr,
-                Box::new(self.right.unwrap()),
+                Box::new(src.right.unwrap()),
             )
-        } else if let Some(func) = self.func {
-            SimpleExpr::FunctionCall(func, self.args)
-        } else if let Some(left) = self.left {
+        } else if let Some(func) = src.func {
+            SimpleExpr::FunctionCall(func, src.args)
+        } else if let Some(left) = src.left {
             left
         } else {
             panic!("incomplete expression")
@@ -1470,10 +1848,9 @@ impl Into<SimpleExpr> for Expr {
     }
 }
 
-#[allow(clippy::from_over_into)]
-impl Into<SelectExpr> for Expr {
-    fn into(self) -> SelectExpr {
-        self.into_simple_expr().into()
+impl From<Expr> for SelectExpr {
+    fn from(src: Expr) -> Self {
+        src.into_simple_expr().into()
     }
 }
 
@@ -1502,7 +1879,7 @@ impl SimpleExpr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE ((`size_w` = 1) AND (`size_h` = 2)) OR ((`size_w` = 3) AND (`size_h` = 4))"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE (("size_w" = 1) AND ("size_h" = 2)) OR (("size_w" = 3) AND ("size_h" = 4))"#
     /// );
     /// ```
     pub fn and(self, right: SimpleExpr) -> Self {
@@ -1533,7 +1910,7 @@ impl SimpleExpr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character`, `size_w`, `size_h` FROM `character` WHERE ((`size_w` = 1) OR (`size_h` = 2)) AND ((`size_w` = 3) OR (`size_h` = 4))"#
+    ///     r#"SELECT "character", "size_w", "size_h" FROM "character" WHERE (("size_w" = 1) OR ("size_h" = 2)) AND (("size_w" = 3) OR ("size_h" = 4))"#
     /// );
     /// ```
     pub fn or(self, right: SimpleExpr) -> Self {
@@ -1567,7 +1944,7 @@ impl SimpleExpr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character` FROM `character` WHERE `size_w` * 2 = `size_h` * 3"#
+    ///     r#"SELECT "character" FROM "character" WHERE "size_w" * 2 = "size_h" * 3"#
     /// );
     /// ```
     pub fn equals<T>(self, right: T) -> Self
@@ -1604,7 +1981,7 @@ impl SimpleExpr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT `character` FROM `character` WHERE `size_w` * 2 <> `size_h`"#
+    ///     r#"SELECT "character" FROM "character" WHERE "size_w" * 2 <> "size_h""#
     /// );
     /// ```
     pub fn not_equals<T>(self, right: T) -> Self
@@ -1640,7 +2017,7 @@ impl SimpleExpr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT MAX(`size_w`) + MAX(`size_h`) FROM `character`"#
+    ///     r#"SELECT MAX("size_w") + MAX("size_h") FROM "character""#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -1677,7 +2054,7 @@ impl SimpleExpr {
     /// );
     /// assert_eq!(
     ///     query.to_string(SqliteQueryBuilder),
-    ///     r#"SELECT MAX(`size_w`) - MIN(`size_w`) FROM `character`"#
+    ///     r#"SELECT MAX("size_w") - MIN("size_w") FROM "character""#
     /// );
     /// ```
     #[allow(clippy::should_implement_trait)]
@@ -1793,4 +2170,41 @@ impl SimpleExpr {
     {
         self.concatenate(right)
     }
+
+    /// Express a `CAST AS` expression.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use sea_query::{tests_cfg::*, *};
+    ///
+    /// let query = Query::select()
+    ///     .expr(Expr::value("1").cast_as(Alias::new("integer")))
+    ///     .to_owned();
+    ///
+    /// assert_eq!(
+    ///     query.to_string(MysqlQueryBuilder),
+    ///     r#"SELECT CAST('1' AS integer)"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(PostgresQueryBuilder),
+    ///     r#"SELECT CAST('1' AS integer)"#
+    /// );
+    /// assert_eq!(
+    ///     query.to_string(SqliteQueryBuilder),
+    ///     r#"SELECT CAST('1' AS integer)"#
+    /// );
+    /// ```
+    pub fn cast_as<T>(self, type_name: T) -> Self
+    where
+        T: IntoIden,
+    {
+        Self::FunctionCall(
+            Function::Cast,
+            vec![self.binary(
+                BinOper::As,
+                Expr::cust(type_name.into_iden().to_string().as_str()),
+            )],
+        )
+    }
 }
